@@ -1,13 +1,7 @@
 # run tests on CI (these tests depend on Chrome)
 
 print_pdf = function(input, output = tempfile(), ...) {
-  chrome_print(
-    input, output,
-    # use --no-sandbox with travis
-    # https://docs.travis-ci.com/user/chrome#sandboxing
-    # extra_args = c('--disable-gpu', '--no-sandbox'),
-    ...
-  )
+  chrome_print(input, output, ...)
 }
 
 if (!is.na(Sys.getenv('CI', NA))) {
